OC.L10N.register(
    "deck",
    {
    "Personal" : "ส่วนตัว",
    "Done" : "Done",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัพโหลดมีขนาดไฟล์ใหญ่เกินจำนวนที่กำหนดไว้ในคำสั่ง MAX_FILE_SIZE ที่ถูกระบุไว้ในรูปแบบของ HTML",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัพโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Cancel" : "ยกเลิก",
    "Details" : "รายละเอียด",
    "Sharing" : "แชร์ข้อมูล",
    "Tags" : "ป้ายกำกับ",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "ลบ",
    "Edit" : "แก้ไข",
    "Due date" : "วันที่ครบกำหนด",
    "Description" : "รายละเอียด",
    "Comments" : "ความคิดเห็น",
    "Modified" : "แก้ไขเมื่อ",
    "Save" : "บันทึก",
    "Reply" : "ตอบกลับ",
    "Update" : "อัพเดท",
    "(group)" : "(กลุ่ม)",
    "seconds ago" : "วินาที ก่อนหน้านี้",
    "Settings" : "ตั้งค่า",
    "Share" : "แชร์"
},
"nplurals=1; plural=0;");
